@@ -188,6 +188,24 @@ pub fn default(event: &Event, jnv: &mut crate::jnv::Jnv) -> anyhow::Result<Promp
             jnv.json.stream.expand_all();
         }
 
+        Event::Key(KeyEvent {
+            code: KeyCode::Char('o'),
+            modifiers: KeyModifiers::CONTROL,
+            kind: KeyEventKind::Press,
+            state: KeyEventState::NONE,
+        }) => {
+            jnv.store_content_to_clipboard();
+        }
+
+        Event::Key(KeyEvent {
+            code: KeyCode::Char('q'),
+            modifiers: KeyModifiers::CONTROL,
+            kind: KeyEventKind::Press,
+            state: KeyEventState::NONE,
+        }) => {
+            jnv.store_query_to_clipboard();
+        }
+
         Event::Key(KeyEvent {
             code: KeyCode::Char('n'),
             modifiers: KeyModifiers::CONTROL,
